@@ -255,6 +255,8 @@ class SeleniumTestCase(LiveServerTestCase):
                                        desired_capabilities=capabilities)
         elif self.browser == 'opera':
             self.sel = RemoteWebDriver(desired_capabilities=DesiredCapabilities.OPERA)
+        elif self.browser == 'iexplore':
+            self.sel = RemoteWebDriver(desired_capabilities=DesiredCapabilities.INTERNETEXPLORER)
         elif self.browser == 'phantomjs':
             self.sel = PhantomJS(service_args=['--debug=true',
                                                '--webdriver-loglevel=DEBUG'])
@@ -263,6 +265,7 @@ class SeleniumTestCase(LiveServerTestCase):
             self.sel = RemoteWebDriver(desired_capabilities=DesiredCapabilities.SAFARI)
         else:
             self.sel = Chrome()
+        self.sel.set_page_load_timeout(settings.SELENIUM_PAGE_LOAD_TIMEOUT)
         # Give the browser a little time; Firefox throws random errors if you
         # hit it too soon
         time.sleep(1)
